Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.classifier.mimlTOmi.miml_to_mi_lp_classifier.MIMLtoMILPClassifier(classifier)

  Bases: `MIMLtoMIClassifier`

  Class to represent a multi-instance classifier using a label powerset transformation

  fit_internal(dataset_train: MIMLDataset) → None

    Training the classifier

    # Parameters

    dataset_train: MIMLDataset

      Dataset to train the classifier

  predict(x: ndarray) → ndarray

    Predict labels of given data

    # Parameters

    xndarray of shape (n_instances, n_features)

      Data to predict their labels

    # Returns

    resultsndarray of shape (n_labels)

      Predicted labels

  predict_proba(dataset_test: MIMLDataset)

    Predict probabilities of given dataset of having a positive label

    # Parameters

    dataset_testMIMLDataset

      Dataset to predict probabilities

    # Returns

    results: np.ndarray of shape (n_instances, n_features)

      Predicted probabilities for given dataset